@@ -3,7 +3,7 @@ astLib - python astronomy modules
 
 (c) 2007-2012 Matt Hilton
 
-(c) 2013 Matt Hilton & Steven Boada
+(c) 2013-2018 Matt Hilton & Steven Boada
 
 U{http://astlib.sourceforge.net}
 
@@ -12,6 +12,5 @@ See the LICENSE file for information on distribution.
 
 """
 
-__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS',
-    'astSED']
-__version__ = '0.7.0'
+__all__=['astCalc', 'astCoords', 'astImages', 'astPlots', 'astStats', 'astWCS', 'astSED']
+__version__ = '0.10.1'
